/*---------------------------------------------------------------------------\
| Project:  PSAS LV2.3 Backup Pyrotechnic System Firmware
|
| File:     bps.h
|
| Descr.:   Main (application) include file
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 05/29/2009 | Created from LV2 Recovery Node.
\---------------------------------------------------------------------------*/

#ifndef _BPS_H     // Don't include more than once (last line = #endif)
#define _BPS_H

//------------------------------------------------------------------------
// Typedefs
//------------------------------------------------------------------------

// None

//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------

// BPS Defines

#define BPS_DISARMED 	0xAA
#define BPS_ARMED		0x55

#define	LOW				0
#define	HIGH			1

#define PYRO_FIRE_KEY	0xD3

// Port pin definitions

// --------------------- PORT B

#define PYRO_PORT		PORTB
#define PYRO_ONE_MASK	0b00000001 // PB0
#define PYRO_TWO_MASK	0b00000010 // PB1

#define GRN_LED_PORT    PORTB
#define GRN_LED_TOGGLE	PINB
#define GRN_LED_MASK	0b00000100 // PB2
//#define GRN_LED_MASK	0b00100000 // PB5 (Diecimila board)

// --------------------- PORT C

#define DTMF_PORT		PINC
#define DTMF_MASK		0b00001111 //PC0 - PC3

#define BUZZER_PORT     PORTC
#define BUZZER_TOGGLE	PINC
#define	BUZZER_MASK		0b00010000	// PC4

// --------------------- PORT D

#define TONE_VALID_PORT	PIND
#define TONE_VALID_MASK	0b00000100	// PD2

// DTMF Defines

/* Recovery Node v1.2 port C Bits 0-3
 * represent DTMF codes. These define the bit patterns that corrospond to
 * each of the 16 possible DTMF codes.
 */

#define DTMF_TONE_ZERO  0b1010   // A
#define DTMF_TONE_ONE   0b0001   // 1
#define DTMF_TONE_TWO   0b0010   // 2
#define DTMF_TONE_THREE 0b0011   // 3
#define DTMF_TONE_FOUR  0b0100   // 4
#define DTMF_TONE_FIVE  0b0101   // 5
#define DTMF_TONE_SIX   0b0110   // 6
#define DTMF_TONE_SEVEN 0b0111   // 7
#define DTMF_TONE_EIGHT 0b1000   // 8
#define DTMF_TONE_NINE  0b1001   // 9
#define DTMF_TONE_STAR  0b1011   // B
#define DTMF_TONE_POUND 0x0C // 0b1100   // C
#define DTMF_TONE_A     0b1101   // D
#define DTMF_TONE_B     0b1110   // E
#define DTMF_TONE_C     0b1111   // F
#define DTMF_TONE_D     0b0000   // 0

//------------------------------------------------------------------------
// Macros
//------------------------------------------------------------------------

// None

//------------------------------------------------------------------------
// Function declarations
//------------------------------------------------------------------------

void 	initialize         (void);
void    process_dtmf_tones (uint8_t);
void 	fire_pyro          (uint8_t number, uint8_t key);

//------------------------------------------------------------------------
// External Global variable declarations
//------------------------------------------------------------------------

// None

// extern bit  recovery_20ms_tick;

//------------------------------------------------------------------------

#endif  // _BPS_H
